.. _api-queryset:

QuerySet
--------

.. _api-queryset-all:

``all()``
^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.all

.. _api-queryset-filter:

``filter``
^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.filter

.. _api-queryset-exclude:

``exclude``
^^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.exclude

.. _api-queryset-update:

``update``
^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.update

.. _api-queryset-delete:

``delete``
^^^^^^^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.delete

.. _api-queryset-update-all:

``update_all``
^^^^^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.update_all

.. _api-queryset-delete-all:

``delete_all``
^^^^^^^^^^^^^^

.. automethod:: protean.core.entity.QuerySet.delete_all

